<?php

/*
 * Theme Customize Options
 * @package nextpage
 * @since 1.0.0
 * */

if ( ! defined( 'ABSPATH' ) ) {
	exit(); // exit if access directly
}

if ( class_exists( 'CSF' ) ) {
	$nextpage_prefix = 'nextpage';

	CSF::createCustomizeOptions( $nextpage_prefix . '_customize_options' );

	/*-------------------------------------
		** Theme Main Color
	-------------------------------------*/
	CSF::createSection( $nextpage_prefix . '_customize_options', array(
		'title'    => esc_html__( '01. Nextpage Primary Color', 'nextpage' ),
		'priority' => 10,
		'fields'   => array(
			array(
				'id'      => 'main_color',
				'type'    => 'color',
				'title'   => esc_html__( 'Theme Main Color', 'nextpage' ),
				'default' => '#2979FF',
				'desc'    => esc_html__( 'This is theme primary color, means it\'ll affect most of elements that have default color of our theme primary color', 'nextpage' )
			),
		)
	) );
	/*-------------------------------------
		** Theme Header Options
	-------------------------------------*/
	CSF::createSection( $nextpage_prefix . '_customize_options', array(
		'title'    => esc_html__( '02. Nextpage Header', 'nextpage' ),
		'priority' => 11,
		'fields'   => array(
			array(  //nav bar one start
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Header Style One', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'topbar_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Color', 'nextpage' ),
				'output'      => '.navone .topbar-area ',
				'output_mode' => 'color',
				'output'      => array( '.navone .topbar-area ', '.navone .topbar-area ul li a' ),
				'default'     => 'rgba(255, 255, 255, 0.8)',
			),
			array(
				'id'          => 'tobar_bg_color_navone',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Background Color', 'nextpage' ),
				'output'      => '.navone .topbar-area',
				'output_mode' => 'background-color',
				'default'     => '#1c3459'
			),
			array(
				'id'          => 'logo_bg_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Logo Area Background Color', 'nextpage' ),
				'output'      => '.navone .adbar-area',
				'output_mode' => 'background-color',
				'default'     => '#fff'
			),
			array(
				'id'          => 'menu_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Color', 'nextpage' ),
				'output'      => array( '.navone.navbar-area .nav-container .navbar-collapse .navbar-nav li a, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:before, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:after' ),
				'output_mode' => 'color',
				'default'     => '#fff'
			),
			array(
				'id'          => 'menu_icon_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Icon Color', 'nextpage' ),
				'output'      => array( '.navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:before, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:after' ),
				'output_mode' => 'background-color',
				'default'     => '#fff'
			),
			array(
				'id'          => 'menu_bg_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Background Color', 'nextpage' ),
				'output'      => array( '.navone.navbar-area .navbar, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children .sub-menu li:hover ' ),
				'output_mode' => 'background-color',
				'default'     => '#2979ff'
			),
			array(
				'id'          => 'search_bg_color_one',
				'type'        => 'color',
				'title'       => esc_html__( 'Search Background Color', 'nextpage' ),
				'output'      => '.navone.navbar-area .menu-search-inner',
				'output_mode' => 'background-color',
				'default'     => '#086ed5'
			),
			array(  //nav bar two start
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Header Stye Two', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'topbar_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Color', 'nextpage' ),
				'output'      => '.navtwo .topbar-area ',
				'output_mode' => 'color',
				'output'      => array( '.navtwo .topbar-area ', '.navtwo .topbar-area ul li a' ),
				'default'     => 'rgba(255, 255, 255, 0.8)',
			),
			array(
				'id'          => 'tobar_bg_color_navtwo',
				'type'        => 'color',
				'title'       => esc_html__( 'Topbar Background Color', 'nextpage' ),
				'output'      => '.navtwo .topbar-area',
				'output_mode' => 'background-color',
				'default'     => '#1c3459'
			),
			array(
				'id'          => 'logo_bg_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Logo Area Background Color', 'nextpage' ),
				'output'      => '.navtwo .adbar-area',
				'output_mode' => 'background-color',
				'default'     => '#102950'
			),
			array(
				'id'          => 'menu_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Color', 'nextpage' ),
				'output'      => array( '.navtwo.navbar-area .nav-container .navbar-collapse .navbar-nav li a, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:before, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:after' ),
				'output_mode' => 'color',
				'default'     => '#fff'
			),
			array(
				'id'          => 'menu_icon_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Icon Color', 'nextpage' ),
				'output'      => array( '.navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:before, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children:after' ),
				'output_mode' => 'background-color',
				'default'     => '#fff'
			),
			array(
				'id'          => 'menu_bg_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Menu Background Color', 'nextpage' ),
				'output'      => array( '.navtwo.navbar-area .navbar, .navbar-area .nav-container .navbar-collapse .navbar-nav li.menu-item-has-children .sub-menu li:hover ' ),
				'output_mode' => 'background-color',
				'default'     => '#2979ff'
			),
			array(
				'id'          => 'search_bg_color_two',
				'type'        => 'color',
				'title'       => esc_html__( 'Search Background Color', 'nextpage' ),
				'output'      => '.navtwo.navbar-area .menu-search-inner',
				'output_mode' => 'background-color',
				'default'     => '#086ed5'
			),
		)
	) );
	/*-------------------------------------
	  ** Theme Sidebar Options
  -------------------------------------*/
	CSF::createSection( $nextpage_prefix . '_customize_options', array(
		'title'    => esc_html__( '03. Nextpage Main Body', 'nextpage' ),
		'priority' => 13,
		'fields'   => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Main Body Options', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'header_color',
				'type'        => 'color',
				'title'       => esc_html__( 'All Header Color', 'nextpage' ),
				'default'     => '#201654',
				'output_mode' => 'color',
				'output'      => array( 'h1, h2, h3, h4, h5, h6' ),
			),
			array(
				'id'          => 'txt_Color',
				'type'        => 'color',
				'title'       => esc_html__( 'Body Text Color', 'nextpage' ),
				'default'     => '#696969',
				'output_mode' => 'color',
				'output'      => array( 'p', '.single-blog-inner .single-blog-details p' ),
			),
		)
	) );
	/*-------------------------------------
		** Theme Footer Options
	-------------------------------------*/
	CSF::createSection( $nextpage_prefix . '_customize_options', array(
		'title'    => esc_html__( '04. Nextpage Footer', 'nextpage' ),
		'priority' => 14,
		'fields'   => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Footer Options', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'footer_area_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Footer Background Color', 'nextpage' ),
				'default'     => '#102950',
				'output_mode' => 'background-color',
				'output'      => '.footer-top-section',
			),
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Footer Widget Options', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'footer_widget_title_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Footer Widget Title Color', 'nextpage' ),
				'default'     => '#fff',
				'output_mode' => 'color',
				'output'      => '.footer-area .widget-title'
			),
			array(
				'id'          => 'footer_widget_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Footer Widget Text Color', 'nextpage' ),
				'default'     => 'rgba(255, 255, 255, 0.7)',
				'output_mode' => 'color',
				'output'      => array(
					'.footer-area .nextpage-footer-top p',
					'footer-area .nextpage-footer-top a',
					'.footer-area .nextpage-footer-top ul li a',
					'.nextpage-footer-top h6 a',
					'.footer-area .nextpage-footer-top .date i'
				)
			),
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__( 'Copyright Area Options', 'nextpage' ) . '</h3>'
			),
			array(
				'id'          => 'copyright_area_bg_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Copyright Area Background Color', 'nextpage' ),
				'default'     => '#102950',
				'output_mode' => 'background-color',
				'output'      => '.nextpage-footer-bottom',
			),
			array(
				'id'          => 'copyright_area_text_color',
				'type'        => 'color',
				'title'       => esc_html__( 'Copyright Area Text Color', 'nextpage' ),
				'default'     => 'rgba(255, 255, 255, 0.7)',
				'output_mode' => 'color',
				'output'      => '.footer-bottom p',
			),
		)
	) );


}//endif