<?php
// Control core classes for avoid errors
if (class_exists('CSF')) {
	$nextpage_allowed_html = Nextpage_Function('Functions')->kses_allowed_html(array('mark'));

	//
	// Set a unique slug-like ID
	$nextpage_prefix = 'nextpage';

	//
	// Create options
	CSF::createOptions($nextpage_prefix . '_theme_options', array(
		'menu_title'      => 'Theme Option',
		'menu_slug'       => 'nextpage-theme-option',
		'menu_type'       => 'submenu',
		'enqueue_webfont' => true,
		'show_footer'     => false,
		'footer_credit'           => 'Solverwp.com',
		'framework_title' => NEXTPAGE_NAME . ' <small>V- ' . esc_html(NEXTPAGE_VERSION) . esc_html__(' By ', 'nextpage') . '<a href="' . esc_url(NEXTPAGE_AUTHOR_URI) . '" target="_blank">' . NEXTPAGE_AUTHOR . '</a> </small>',
	));

	//
	// Create a section
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => 'General',
		'icon'   => 'fa fa-wrench',
		'fields' => array(

			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Preloader Options', 'nextpage') . '</h3>'
			),
			array(
				'id'      => 'preloader_enable',
				'title'   => esc_html__('Preloader', 'nextpage'),
				'type'    => 'switcher',
				'desc'    => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable preloader', 'nextpage'), $nextpage_allowed_html),
				'default' => true,
			),
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Back Top Options', 'nextpage') . '</h3>'
			),
			array(
				'id'      => 'back_top_enable',
				'title'   => esc_html__('Back Top', 'nextpage'),
				'type'    => 'switcher',
				'desc'    => wp_kses(__('you can set <mark>Yes / No</mark> to show/hide back to top', 'nextpage'), $nextpage_allowed_html),
				'default' => true,
			),

		)
	));

	/*-------------------------------------------------------
	   ** Entire Site Header  Options
	 --------------------------------------------------------*/
	CSF::createSection(
		$nextpage_prefix . '_theme_options',
		array(
			'title' => esc_html__('Header Option', 'nextpage'),
			'id'    => 'entire_site_header_options',
			'icon'  => 'fa fa-header'
		)
	);
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Theme Logos', 'nextpage'),
		'id'     => 'logo_options',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'entire_site_header_options',
		'fields' => array(
			array(
				'id'      => 'header_style', // Header Style
				'type'    => 'button_set',
				'title'   => esc_html__('Header Style', 'nextpage'),
				'options' => array(
					'premade-header' => esc_html__('Pre Made Header', 'nextpage'),
					'header-builder' => esc_html__('Header Builder', 'nextpage'),
				),
				'default' => 'premade-header',
			),
			array(
				'type'       => 'subheading',
				'content'    => '<h3>' . esc_html__('Premade Header Options', 'nextpage') . '</h3>',
				'dependency' => array('header_style', '==', 'premade-header'),
			),
			//
			// nav select
			array(
				'id'         => 'nav_menu',
				'type'       => 'image_select',
				'dependency' => array('header_style', '==', 'premade-header'),
				'title'      => esc_html__('Select Header Style', 'nextpage'),
				'options'    => array(
					'header-one' => NEXTPAGE_THEME_OPTIONS_IMG . '/nav/nav-01.png',
					'header-two' => NEXTPAGE_THEME_OPTIONS_IMG . '/nav/nav-02.png',
				),
				'default'    => 'header-one'
			),
			array(
				'id'         => 'logo_nav_one',
				'title'      => esc_html__('Upload Logo ', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'desc'       => wp_kses(__(' NT: this logo will overwrite <mark>Customizer>Site Identity</mark> uploaded logo', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-one'),
				),
			),
			array(
				'id'         => 'logo_nav_one_mobile',
				'title'      => esc_html__('Upload Mobile Logo', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'desc'       => wp_kses(__(' NT: this logo will overwrite <mark>Customizer>Site Identity</mark> uploaded logo', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-one'),
				),
			),
			array(
				'id'         => 'logo_nav_two',
				'title'      => esc_html__('Upload Logo', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'desc'       => wp_kses(__(' NT: this logo will overwrite <mark>Customizer>Site Identity</mark> uploaded logo', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-two'),
				),
			),
			array(
				'id'         => 'logo_nav_two_mobile',
				'title'      => esc_html__('Upload Mobile Logo', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'desc'       => wp_kses(__(' NT: this logo will overwrite <mark>Customizer>Site Identity</mark> uploaded logo', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-two'),
				),
			),
			array(
				'type'       => 'subheading',
				'content'    => '<h3>' . esc_html__('Top Bar Option', 'nextpage') . '</h3>',
				'dependency' => array('header_style', '==', 'premade-header'),
			),
			array(
				'id'         => 'top_bar_enable',
				'title'      => esc_html__('Enable Top Bar', 'nextpage'),
				'type'       => 'switcher',
				'desc'       => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable top bar', 'nextpage'), $nextpage_allowed_html),
				'default'    => true,
				'dependency' => array('header_style', '==', 'premade-header'),
			),
			array(
				'id'          => 'select-topbar-menu',
				'type'        => 'select',
				'title'       => esc_html__('Select Menu For Topbar', 'nextpage'),
				'placeholder' => esc_html__('Select an menu', 'nextpage'),
				'options'     => 'menus',
				'dependency'  =>
				array(
					array('header_style', '==', 'premade-header'),
					array('top_bar_enable', '==', true)
				),
			),
			array(
				'id'         => 'topbar-social-icon',
				'type'       => 'repeater',
				'title'      => esc_html__('Social Profile', 'nextpage'),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('top_bar_enable', '==', true)
				),
				'fields'     => array(
					array(
						'id'    => 'icon',
						'type'  => 'icon',
						'title' => esc_html__('Pick Up Your Icon', 'nextpage'),
					),
					array(
						'id'    => 'link',
						'type'  => 'text',
						'title' => esc_html__('Inter Social Url', 'nextpage'),
					),
					array(
						'id'      => 'color',
						'type'    => 'color',
						'title'   => esc_html__('Icon Background Color', 'nextpage'),
						'default' => '#3b5998'
					),

				),
			),
			array(
				'id'         => 'search_enable_menu_one',
				'title'      => esc_html__('Display Search ', 'nextpage'),
				'type'       => 'switcher',
				'desc'       => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable search in menu', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-one'),
				),
			),
			array(
				'id'         => 'search_enable_menu_two',
				'title'      => esc_html__('Display Search', 'nextpage'),
				'type'       => 'switcher',
				'desc'       => wp_kses(__('you can set <mark>Yes / No</mark> to enable/disable search in menu', 'nextpage'), $nextpage_allowed_html),
				'dependency' =>
				array(
					array('header_style', '==', 'premade-header'),
					array('nav_menu', '==', 'header-two'),
				),
			),
			array(
				'id'         => 'add_image',
				'title'      => esc_html__('Advertise Image', 'nextpage'),
				'desc'       => esc_html__('Upload Advertise Image', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'dependency' => array('header_style', '==', 'premade-header'),
			),
			array(
				'id'         => 'add_link',
				'title'      => esc_html__('Advertise Link', 'nextpage'),
				'type'       => 'text',
				'info'       => esc_html__('Enter Advertise Image Link', 'nextpage'),
				'dependency' => array('header_style', '==', 'premade-header'),
				'default'    => '#'
			),
			array(
				'id'          => 'header-builder',
				'type'        => 'select',
				'title'       => esc_html__('Select Header', 'nextpage'),
				'placeholder' => esc_html__('Select a Header', 'nextpage'),
				'options'     => Nextpage_Function('Functions')->get_header_builder_library(),
				'dependency'  => array('header_style', '==', 'header-builder'),
				'desc'        => esc_html__("You need to create first header from header builder", 'nextpage')

			),
		)
	));
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Breadcrumb', 'nextpage'),
		'id'     => 'breadcrumb_options',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'entire_site_header_options',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Breadcrumb Options', 'nextpage') . '</h3>'
			),
			array(
				'id'      => 'breadcrumb_enable',
				'title'   => esc_html__('Breadcrumb', 'nextpage'),
				'type'    => 'switcher',
				'desc'    => wp_kses(__('you can set <mark>Yes / No</mark> to show/hide breadcrumb', 'nextpage'), $nextpage_allowed_html),
				'default' => true,
			),
		)
	));

	/*-------------------------------------------------------
	   ** Pages and Template
	 --------------------------------------------------------*/
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'id'    => 'pages_and_template',
		'title' => esc_html__('Pages & Template', 'nextpage'),
		'icon'  => 'fa fa-files-o'
	));

	// blog optoins
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Blog Page', 'nextpage'),
		'id'     => 'blog_page',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'pages_and_template',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Blog Page Option', 'nextpage') . '</h3>'
			),
			array(
				'id'      => $nextpage_prefix . '_blog_layout',
				'type'    => 'image_select',
				'title'   => esc_html__('Select Page Layout', 'nextpage'),
				'options' => array(
					'full-width'    => NEXTPAGE_THEME_OPTIONS_IMG . '/page/D.png',
					'left-sidebar'  => NEXTPAGE_THEME_OPTIONS_IMG . '/page/L.png',
					'right-sidebar' => NEXTPAGE_THEME_OPTIONS_IMG . '/page/R.png',
				),
				'default' => 'right-sidebar'
			),
			array(
				'type'  => 'switcher',
				'id'    => 'blog_author_enable',
				'title' => esc_html__('Display Author Name', 'nextpage'),
			),
			array(
				'type'  => 'switcher',
				'id'    => 'blog_date_enable',
				'title' => esc_html__('Display Date', 'nextpage'),
			),
			array(
				'type'  => 'switcher',
				'id'    => 'blog_category_enable',
				'title' => esc_html__('Display Category', 'nextpage'),
			),
			array(
				'type'  => 'switcher',
				'id'    => 'blog_commnet_enable',
				'title' => esc_html__('Display Comment Count', 'nextpage'),
			),
			array(
				'type'    => 'switcher',
				'id'      => 'blog_spacing_enable',
				'title'   => esc_html__('Blog Page Spacing', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to enable blog page spacing', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'id'         => 'blog_top_padding',
				'title'      => esc_html__('Blog Page Spacing Top', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Top</mark> for Blog Page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('blog_spacing_enable', '==', 'true')
			),
			array(
				'id'         => 'blog_bottom_padding',
				'title'      => esc_html__('Blog Page Spacing Bottom', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Bottom</mark> for Blog page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('blog_spacing_enable', '==', 'true')
			),
		)
	));

	// blog single optoins
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Blog Single Page', 'nextpage'),
		'id'     => 'single_page',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'pages_and_template',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Blog Single Page Option', 'nextpage') . '</h3>'
			),
			array(
				'id'      => $nextpage_prefix . '_single_page_layout',
				'type'    => 'image_select',
				'title'   => esc_html__('Select Page Layout', 'nextpage'),
				'options' => array(
					'full-width'    => NEXTPAGE_THEME_OPTIONS_IMG . '/page/D.png',
					'left-sidebar'  => NEXTPAGE_THEME_OPTIONS_IMG . '/page/L.png',
					'right-sidebar' => NEXTPAGE_THEME_OPTIONS_IMG . '/page/R.png',
				),
				'default' => 'right-sidebar'
			),
			array(
				'type'    => 'switcher',
				'id'      => 'releted_post',
				'title'   => esc_html__('Display Related Post', 'nextpage'),
				'default' => false
			),
			array(
				'type'    => 'switcher',
				'id'      => 'social_share',
				'title'   => esc_html__('Display Social Share', 'nextpage'),
				'default' => false
			),
			array(
				'type'    => 'switcher',
				'id'      => 'blog_details_spacing_enable',
				'title'   => esc_html__('Blog Details Page Spacing', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to enable blog details page spacing', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'id'         => 'single_top_padding',
				'title'      => esc_html__('Blog Single Page Spacing Top', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Top</mark> for Blog Single Page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('blog_details_spacing_enable', '==', 'true')
			),
			array(
				'id'         => 'single_bottom_padding',
				'title'      => esc_html__('Blog Single Page Spacing Bottom', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Bottom</mark> for Blog Single page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('blog_details_spacing_enable', '==', 'true')
			),
		)
	));

	// archive page optoins
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Archive  Page', 'nextpage'),
		'id'     => 'archive_page',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'pages_and_template',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Archive Page Option', 'nextpage') . '</h3>'
			),
			array(
				'id'      => $nextpage_prefix . '_archive_layout',
				'type'    => 'image_select',
				'title'   => esc_html__('Select Page Layout', 'nextpage'),
				'options' => array(
					'full-width'    => NEXTPAGE_THEME_OPTIONS_IMG . '/page/D.png',
					'left-sidebar'  => NEXTPAGE_THEME_OPTIONS_IMG . '/page/L.png',
					'right-sidebar' => NEXTPAGE_THEME_OPTIONS_IMG . '/page/R.png',
				),
				'default' => 'right-sidebar'
			),
			array(
				'type'    => 'switcher',
				'id'      => 'archive_page_spacing_enable',
				'title'   => esc_html__('Archive Page Spacing', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to enable archive page spacing', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'id'         => 'archive_top_padding',
				'title'      => esc_html__('Archive  Page Spacing Top', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Top</mark> for  Archive page  container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 220,
				'dependency' => array('archive_page_spacing_enable', '==', 'true')
			),
			array(
				'id'         => 'archive_bottom_padding',
				'title'      => esc_html__('Archive Page Spacing Bottom', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Bottom</mark> for Archive page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 220,
				'dependency' => array('archive_page_spacing_enable', '==', 'true')
			),
		)
	));

	// search page optoins
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Search  Page', 'nextpage'),
		'id'     => 'search_page',
		'icon'   => 'fa fa-ellipsis-h',
		'parent' => 'pages_and_template',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Search Page Option', 'nextpage') . '</h3>'
			),
			array(
				'id'      => $nextpage_prefix . '_search_layout',
				'type'    => 'image_select',
				'title'   => esc_html__('Select Page Layout', 'nextpage'),
				'options' => array(
					'full-width'    => NEXTPAGE_THEME_OPTIONS_IMG . '/page/D.png',
					'left-sidebar'  => NEXTPAGE_THEME_OPTIONS_IMG . '/page/L.png',
					'right-sidebar' => NEXTPAGE_THEME_OPTIONS_IMG . '/page/R.png',
				),
				'default' => 'right-sidebar'
			),
			array(
				'type'    => 'switcher',
				'id'      => 'search_page_spacing_enable',
				'title'   => esc_html__('Search Page Spacing', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to enable search page spacing', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'id'         => 'search_top_padding',
				'title'      => esc_html__('Search  Page Spacing Top', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Top</mark> for search page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('search_page_spacing_enable', '==', 'true')
			),
			array(
				'id'         => 'search_bottom_padding',
				'title'      => esc_html__('Search Page Spacing Bottom', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>Padding Bottom</mark> for search page container.', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 20,
				'dependency' => array('search_page_spacing_enable', '==', 'true')
			),
		)
	));


	/*  404 page options */
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'id'     => '404_page',
		'title'  => esc_html__('404 Page', 'nextpage'),
		'parent' => 'pages_and_template',
		'icon'   => 'fa fa-exclamation-triangle',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('404 Page Options', 'nextpage') . '</h3>',
			),
			array(
				'id'         => '404_title',
				'title'      => esc_html__('Title', 'nextpage'),
				'type'       => 'text',
				'info'       => wp_kses(__('you can change <mark>title</mark> of 404 page', 'nextpage'), $nextpage_allowed_html),
				'attributes' => array('placeholder' => esc_html__('404', 'nextpage'))
			),
			array(
				'id'         => '404_subtitle',
				'title'      => esc_html__('Sub Title', 'nextpage'),
				'type'       => 'text',
				'info'       => wp_kses(__('you can change <mark>sub title</mark> of 404 page', 'nextpage'), $nextpage_allowed_html),
				'attributes' => array('placeholder' => esc_html__('Sorry. we couldn\'t find that page', 'nextpage'))
			),
			array(
				'id'         => '404_button_text',
				'title'      => esc_html__('Button Text', 'nextpage'),
				'type'       => 'text',
				'info'       => wp_kses(__('you can change <mark>button text</mark> of 404 page', 'nextpage'), $nextpage_allowed_html),
				'attributes' => array('placeholder' => esc_html__('Go Back', 'nextpage'))
			)
		)
	));

	/*-------------------------------------------------------
	   ** Typography  Options
  --------------------------------------------------------*/
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'id'     => 'typography',
		'title'  => esc_html__('Typography', 'nextpage'),
		'icon'   => 'fa fa-text-width',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Body Font Options', 'nextpage') . '</h3>',
			),
			array(
				'type'    => 'switcher',
				'id'      => 'body_font_enable',
				'title'   => esc_html__('Body Font', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to select different body font', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'type'           => 'typography',
				'title'          => esc_html__('Typography', 'nextpage'),
				'id'             => 'nextpage_body_font',
				'default'        => array(
					'font-family' => 'Rubik',
					'font-size'   => '16',
					'line-height' => '26',
					'unit'        => 'px',
					'type'        => 'google',
				),
				'color'          => false,
				'subset'         => false,
				'text_align'     => false,
				'text_transform' => false,
				'letter_spacing' => false,
				'desc'           => wp_kses(__('you can set <mark>font</mark> for all html tags (if not use different heading font)', 'nextpage'), $nextpage_allowed_html),
				'dependency'     => array('body_font_enable', '==', 'true')
			),
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Heading Font Options', 'nextpage') . '</h3>',
			),
			array(
				'type'    => 'switcher',
				'id'      => 'heading_font_enable',
				'title'   => esc_html__('Heading Font', 'nextpage'),
				'desc'    => wp_kses(__('you can set <mark>yes</mark> to select different heading font', 'nextpage'), $nextpage_allowed_html),
				'default' => false
			),
			array(
				'type'           => 'typography',
				'title'          => esc_html__('Typography', 'nextpage'),
				'id'             => 'heading_font',
				'default'        => array(
					'font-family' => 'Rubik',
					'type'        => 'google',
				),
				'color'          => false,
				'subset'         => false,
				'text_align'     => false,
				'text_transform' => false,
				'letter_spacing' => false,
				'font_size'      => false,
				'line_height'    => false,
				'desc'           => wp_kses(__('you can set <mark>font</mark> for  for heading tag .eg: h1,h2mh3,h4,h5,h6', 'nextpage'), $nextpage_allowed_html),
				'dependency'     => array('heading_font_enable', '==', 'true')
			),
		)
	));

	/*-------------------------------------------------------
		 ** Footer  Options
	--------------------------------------------------------*/
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Footer', 'nextpage'),
		'id'     => 'footer_options',
		'icon'   => 'fa fa-copyright',
		'fields' => array(
			array(
				'type'    => 'subheading',
				'content' => '<h3>' . esc_html__('Footer Options', 'nextpage') . '</h3>'
			),
			array(
				'id'      => 'footer_type', // footer Style
				'type'    => 'button_set',
				'title'   => esc_html__('Footer Style', 'nextpage'),
				'options' => array(
					'premade-footer' => esc_html__('Pre Made Footer', 'nextpage'),
					'footer-builder' => esc_html__('Footer Builder', 'nextpage'),
				),
				'default' => 'premade-footer',
			),
			array(
				'id'         => 'footer_style',
				'type'       => 'image_select',
				'title'      => esc_html__('Select Footer Style', 'nextpage'),
				'dependency' => array('footer_type', '==', 'premade-footer'),
				'options'    => array(
					'footer-1' => NEXTPAGE_THEME_OPTIONS_IMG . '/footer/footer-01.png',
					'footer-2' => NEXTPAGE_THEME_OPTIONS_IMG . '/footer/footer-02.png',
				),
				'default'    => 'footer-1'
			),
			array(
				'id'         => 'footer_logo',
				'title'      => esc_html__('Upload Footer Logo', 'nextpage'),
				'type'       => 'media',
				'library'    => 'image',
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('footer_style', '==', 'footer-2')
				)
			),
			array(
				'id'         => 'footer-social-icon',
				'type'       => 'repeater',
				'title'      => esc_html__('Social Icon', 'nextpage'),
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('footer_style', '==', 'footer-2')
				),
				'fields'     => array(
					array(
						'id'    => 'icon',
						'type'  => 'icon',
						'title' => esc_html__('Pick Up Your Icon', 'nextpage'),
					),
					array(
						'id'    => 'link',
						'type'  => 'text',
						'title' => esc_html__('Inter Social Url', 'nextpage'),
					),
					array(
						'id'    => 'color',
						'type'  => 'color',
						'title' => esc_html__('Icon Background Color', 'nextpage'),
					),
				),
			),
			array(
				'id'          => 'select-footer-menu',
				'type'        => 'select',
				'title'       => esc_html__('Select Menu For Footer', 'nextpage'),
				'placeholder' => esc_html__('Select Menu', 'nextpage'),
				'options'     => 'menus',
				'dependency'  => array(
					array('footer_type', '==', 'premade-footer'),
					array('footer_style', '==', 'footer-2')
				)
			),
			array(
				'id'         => 'footer_spacing',
				'title'      => esc_html__('Footer Spacing', 'nextpage'),
				'type'       => 'switcher',
				'desc'       => wp_kses(__('you can set <mark>Yes / No</mark> to set footer spacing', 'nextpage'), $nextpage_allowed_html),
				'default'    => false,
				'dependency' => array('footer_type', '==', 'premade-footer')
			),
			array(
				'id'         => 'footer_top_spacing',
				'title'      => esc_html__('Footer Top Spacing', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>padding</mark> for footer top', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 0,
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('footer_spacing', '==', true)
				)
			),
			array(
				'id'         => 'footer_bottom_spacing',
				'title'      => esc_html__('Footer Bottom Spacing', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>padding</mark> for footer bottom', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'default'    => 0,
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('footer_spacing', '==', true)
				)
			),
			array(
				'type'       => 'subheading',
				'content'    => '<h3>' . esc_html__('Footer Copyright Area Options', 'nextpage') . '</h3>',
				'dependency' => array('footer_type', '==', 'premade-footer')
			),
			array(
				'id'         => 'copyright_text',
				'title'      => esc_html__('Copyright Area Text', 'nextpage'),
				'type'       => 'text',
				'desc'       => wp_kses(__('enter copyright text', 'nextpage'), $nextpage_allowed_html),
				'dependency' => array('footer_type', '==', 'premade-footer')
			),
			array(
				'id'         => 'copyright_area_spacing',
				'title'      => esc_html__('Copyright Area Spacing', 'nextpage'),
				'type'       => 'switcher',
				'desc'       => wp_kses(__('you can set <mark>Yes / No</mark> to set copyright area spacing', 'nextpage'), $nextpage_allowed_html),
				'default'    => false,
				'dependency' => array('footer_type', '==', 'premade-footer')
			),
			array(
				'id'         => 'copyright_area_top_spacing',
				'title'      => esc_html__('Copyright Area Top Spacing', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>padding</mark> for copyright area top', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('copyright_area_spacing', '==', true)
				)
			),
			array(
				'id'         => 'copyright_area_bottom_spacing',
				'title'      => esc_html__('Copyright Area Bottom Spacing', 'nextpage'),
				'type'       => 'slider',
				'desc'       => wp_kses(__('you can set <mark>padding</mark> for copyright area bottom', 'nextpage'), $nextpage_allowed_html),
				'min'        => 0,
				'max'        => 500,
				'step'       => 1,
				'unit'       => 'px',
				'dependency' => array(
					array('footer_type', '==', 'premade-footer'),
					array('copyright_area_spacing', '==', true)
				)
			),
			array(
				'id'          => 'footer-builder-id',
				'type'        => 'select',
				'title'       => esc_html__('Select Footer', 'nextpage'),
				'placeholder' => esc_html__('Select a Footer', 'nextpage'),
				'options'     => Nextpage_Function('Functions')->get_footer_builder_library(),
				'desc'        => esc_html__("You need to create first footer from footer builder", 'nextpage'),
				'dependency'  => array('footer_type', '==', 'footer-builder')
			),
		)
	));


	// Backup section
	CSF::createSection($nextpage_prefix . '_theme_options', array(
		'title'  => esc_html__('Backup', 'nextpage'),
		'id'     => 'backup_options',
		'icon'   => 'fa fa-window-restore',
		'fields' => array(
			array(
				'type' => 'backup',
			),
		)
	));


	//
	// Create taxonomy options
	CSF::createTaxonomyOptions($nextpage_prefix, array(
		'taxonomy'  => array('category'),
		'data_type' => 'serialize', // The type of the database save options. `serialize` or `unserialize`
	));

	//
	// Create a section
	CSF::createSection($nextpage_prefix, array(
		'fields' => array(
			array(
				'id'      => 'catcolor',
				'type'    => 'color',
				'title'   => esc_html__('Text Color', 'nextpage'),
				'default' => '#fff'
			),
			array(
				'id'      => 'cathovercolor',
				'type'    => 'color',
				'title'   => esc_html__('Hover Text Color', 'nextpage'),
				'default' => '#fff'
			),
			array(
				'id'      => 'bgcolor',
				'type'    => 'color',
				'title'   => esc_html__('Background Color', 'nextpage'),
				'default' => '#097bed'
			),
			array(
				'id'      => 'bg_hover_color',
				'type'    => 'color',
				'title'   => esc_html__('Background Color', 'nextpage'),
				'default' => '#097bed'
			),
			array(
				'id'      => 'cat_img',
				'title'   => esc_html__('Small Image', 'nextpage'),
				'type'    => 'media',
				'height'  => 175,
				'width'  => 75,
				'library' => 'image',
			),
			array(
				'id'      => 'cat_lg_img', //category large image
				'title'   => esc_html__('Large Image', 'nextpage'),
				'height'  => 760,
				'width'  => 321,
				'type'    => 'media',
				'library' => 'image',
			),

		)
	));
}
